Module: SequentialFile
- Defined in:
- lib/sequential_file.rb,
lib/sequential_file/base.rb,
lib/sequential_file/namer.rb,
lib/sequential_file/version.rb,
lib/sequential_file/counter_finder.rb
Overview
SequentialFile::Base is not loaded by default, because it is a reference implementation, and third party libs may not need or want it. It can be used by adding the following to any third party lib: require “sequential_file/base”
Defined Under Namespace
Modules: Namer Classes: Base, CounterFinder
Constant Summary collapse
- VERSION =
"0.0.1"