Module: SequentialFile::Namer
- Included in:
- Base
- Defined in:
- lib/sequential_file/namer.rb
Defined Under Namespace
Modules: Initializer
Class Method Summary collapse
-
.included(klass) ⇒ Object
:directory_path - directory path where file will be located :name - complete intelligent and sequential filename :process_date - date stamp of invocation, used as part of filename :filename_first_part - first part of filename, separated from third part by the chronometer :filename_third_part - third part of filename, separated from first part by the chronometer :last_filename_counter - the last-used file counter; prevent files from stepping on each other.
Class Method Details
.included(klass) ⇒ Object
:directory_path - directory path where file will be located :name - complete intelligent and sequential filename :process_date - date stamp of invocation, used as part of filename :filename_first_part - first part of filename, separated from third part by the chronometer :filename_third_part - third part of filename, separated from first part by the chronometer :last_filename_counter - the last-used file counter; prevent files from stepping on each other. :file_extension - the file extension
32 33 34 35 |
# File 'lib/sequential_file/namer.rb', line 32 def self.included(klass) klass.send :prepend, Initializer klass.send :attr_accessor, :directory_path, :name, :process_date, :filename_first_part, :filename_third_part, :last_filename_counter, :file_extension end |